#!/bin/bash

### Custom bash script for
### SmartStart Scripting Toolkit for Linux v1.8
### October 2007
### JimmyV

sleep 10s
clear
setterm -blank 0 -powersave off

### Get environment variables
### must use absolute path here
### exit if file not found

if [ -f /mnt/main/scripts/includes ];
    then
		source /mnt/main/scripts/includes
	else
		echo -e "\n*** includes file not found ***\n" 
		exec /bin/bash  	
fi

echo -e "*** Copying toolkit scripts and utilities to RAM drive ***"
cd ${TOOLKIT}
cp -a ${RAM_TOOLKIT_DIR}/scripts/* ${TOOLKIT}
cp -a ${RAM_TOOLKIT_DIR}/utilities/* ${TOOLKIT}
echo -e "*** Scripts will now continue execution from RAM drive ***"


## With support for ProLiant 100 series systems we use dmidecode
## to get product type and serial number

## occasionally the product name will have whitespace at the end. Our grep output
## has whitespace at the beginning so we use sed to remove the whitespace from each end

echo -e "*** Detecting system type ***\n"

export PRODUCT_NAME="`dmidecode | grep -m1 "Product Name:" | cut -d : -f 2 | sed 's/^[ \t]*//;s/[ \t]*$//'`"
export SERIAL_ID="`dmidecode | grep -m1 "Serial Number:" | cut -d : -f 2 | sed 's/^[ \t]*//;s/[ \t]*$//'`"

## used to create file names. generally don't want any spaces in the file name
# LNAME (Long_Name) is full system name with spaces removed 
export PRODUCT_LNAME="`echo ${PRODUCT_NAME}| tr -d " "`"

# SNAME (Short_Name) drops the word ProLiant 
export PRODUCT_SNAME="`echo ${PRODUCT_NAME} | cut -c 10-`"

echo -e "   -System is a ${PRODUCT_NAME}\n"

## Define system series and architecture

cd ${TOOLKIT}

## system-id file lists all supported systems
source system-id

### tkshell drops to bash prompt with environment loaded
### used for debugging scripts
if [ "${tkshell}" = "1" ];
    then
	## mount writable NFS area just in case we want to save something
	mkdir -p ${RAM_PROFILE_DIR}
	mount -t nfs ${NFS_SERVER_IP}:${NFS_PROFILE_DIR} ${RAM_PROFILE_DIR} -o rw,nolock,sync
	echo -e "*** TKSHELL now active... ***\n"
        exec /bin/bash
fi

### 100 series ProLiant cannot fully use the discovery tools
### 

if [ ${SERIES} = 100 ];
  then

    echo -e "*** 100 Series ProLiant detected, skipping discovery ***"
    echo -e "*** Loading storage & network drivers ***"
    ./load_modules.sh
    echo -e "...Pausing to allow drivers to finish loading\n"
    sleep 2s
    
  else
    ##########################################################
    # !! ONLY USE IF SYSTEM DEFAULTS TO PXE BOOT !!
    #
    # Check EV in BIOS if set to 99 force reboot to hard disk
    #echo -e "*** Checking BIOS EV for DEPLOYE 99\n"
    #./statemgr -R DEPLOY > /dev/null
    #if [ $? = 99 ]; then
    #    echo " BIOS EV set to force local boot"
    #    cd ${TOOLKIT}
    #    reboot C:
    #fi
    #########################################################

  ./hpdiscovery -f ${HWDISC_FILE}

  echo -e "Loading storage & network drivers"
  ./load_modules.sh
  echo -e "...Pausing to allow drivers to finish loading\n"
  sleep 2s

  # running hpdiscovery again to detect discs and controllers
  ./hpdiscovery -f ${HWDISC_FILE}


  ### Set EV in BIOS to 1st phase
  echo -e "*** Setting DEPLOY state to 1 in System ROM ***\n"
  ./statemgr -W DEPLOY 1 > /dev/null
  sleep 5s

  ## add fw=1 on the append line to run firmware update.
  ## or remove if statement to always run firmware update

  ## firmware-update.sh uses the HPSUM utility from the 
  ## firmware maintenance CD
  ## view firmware/README.HPSUM for info on configuration

  if [ "${fw}" = "1" ];
  	then
		./firmware_update.sh
    fi


## end fi for != 100 series
fi

cd ${TOOLKIT}

### default architecture either i386 or x86_64
export ARCH=i386

### default network port
export IFACE=eth0

### default distribution to use during installation
### DISTRO can be on of
### DEBIAN, CENTOS5, REDHAT4.4 REDHAT4.5, REDHAT5.1Server, REDHAT5.2Server, LES9.3, SLES9.4,
### SLES10.1, SLES10.2, SLED10.1, SLED10.2, WINDOWS, SOLARIS
### still developing script for DEBIAN

### Others can be added, land_install.sh and/or land_windows.sh will also need to be updated

export DISTRO=CHANGEME

## under the data_files directory of the toolkit, make a directory
## named the server serial number 
## inside that directory place all the configuration files
## conrep, acu, kickstart, autoyast
## to specify ARCH= , DISTRO= , or IFACE=  place a file called 
## ${SERIAL_ID}.dat 
##
## EXAMPLE:
## system has serial number US222333
## under data_files create a directory called US222333
## under data_files/US222333 create a file called US222333.dat
## inside the file US222333.dat add the variables ARCH=, DISTRO=, and IFACE=
##
## view README file in data_files directory for more info

## if LinuxCOE is being used serial directory and serial file are created 
## and populated with boot image and ks/autoyast file by LinuxCOE
## 
 	
echo "*** Checking for custom settings for system ${SERIAL_ID} ***"
if [ -f ${RAM_DATA_FILES}/${SERIAL_ID}/${SERIAL_ID}.dat ];
    then
	echo -e "   -Custom settings file found\n"
	source ${RAM_DATA_FILES}/${SERIAL_ID}/${SERIAL_ID}.dat
	export ARCH DISTRO IFACE
    else
	echo -e "   -Custom settings not defined\n" 
    # LinuxCOE usage requires SERIAL_ID
    # else
	# echo -e "  -Custom settings not defined" 
	# echo -e "  -LinuxCOE requires serial number directory\n" 
	# exec /bin/bash" 	
fi

case "$DISTRO" in
 
	DEBIAN ) 
            export DISTROFULL="Debian Linux"
	    	    
            ;;

	CENTOS5 ) 
            export DISTROFULL="CentOS 5"
	    	    
            ;;

	REDHAT4.5 ) 
            export DISTROFULL="Red Hat Enterprise Linux 4.5"
	    	    
            ;;

	REDHAT4.6 ) 
            export DISTROFULL="Red Hat Enterprise Linux 4.6"
	    	    
            ;;

	REDHAT5.1Server ) 
            export DISTROFULL="Red Hat Enterprise Linux 5.1"
	    	    
            ;;

	REDHAT5.2Server ) 
            export DISTROFULL="Red Hat Enterprise Linux 5.2"
	    	    
            ;;

	SLES9.3 ) 
	    export DISTROFULL="SUSE Linux Enterprise Server 9 SP3"
	    
	    ;;
	    
	SLES9.4 ) 
	    export DISTROFULL="SUSE Linux Enterprise Server 9 SP4"
	    
	    ;;
	    
	SLES10.1 ) 
	    export DISTROFULL="SUSE Linux Enterprise Server 10 SP1"
	    
	    ;;

	SLES10.2 ) 
	    export DISTROFULL="SUSE Linux Enterprise Server 10 SP2"
	    
	    ;;

	SLED10.1 ) 
	    export DISTROFULL="SUSE Linux Enterprise Desktop 10 SP1"
	    
	    ;;

	SLED10.2 ) 
	    export DISTROFULL="SUSE Linux Enterprise Desktop 10 SP2"
	    
	    ;;

	WINDOWS ) 
	    export DISTROFULL="Microsoft Windows Server 2003"
	    
	    ;;

	SOLARIS ) 
	    export DISTROFULL="Solaris x86"
	    
	    ;;
	* ) 
	    echo "Unkown Distribution"
	    exec /bin/bash
	    
	    ;;
esac

echo -e "*** Installation Paramaters ***"    
echo -e "   -Sever               : ${PRODUCT_NAME}\n   -System Architecture : ${ARCH}\n   -Operating System    : ${DISTROFULL}\n"    
sleep 5s

# debug stopping point
# exec /bin/bash

# pass control to configure hardware script
# 100 series systems cannot config hardware 

if [ ${SERIES} = 100 ];
    then
    	if [ "$DISTRO" = "WINDOWS" ];
	    then
        	./land_windows.sh
	    else
    	    	./land_install.sh
	fi
    else
    	./config_hw.sh
fi    

echo "WAH if your seeing this something bad happened!!!!"
exec /bin/bash
